==> centreon-web-24.04.22.tar.gz: centreon-web-24.04.22/packages/ui/src/components/Form/AccessRights/AccessRights.stories.tsx <==
import { Meta, StoryObj } from '@storybook/react';
import { rest } from 'msw';

import { SnackbarProvider } from '../../..';

import AccessRightsForm from './AccessRights';
import {
  accessRightsWithStates,
  buildResult,
  defaultAccessRights,
  emptyAccessRights,
  labels,
  roles
} from './storiesData';

const meta: Meta<typeof AccessRightsForm> = {
  component: AccessRightsForm,
  parameters: {
    msw: {
      handlers: [
        rest.get('api/latest/contact?**', (req, res, ctx) => {
          return res(ctx.json(buildResult(false)));
        }),
        rest.get('api/latest/contactGroup?**', (req, res, ctx) => {
          return res(ctx.json(buildResult(true)));
        })
      ]
    }
  }
};

const Template = (args): JSX.Element => (
  <SnackbarProvider>
    <AccessRightsForm {...args} />
  </SnackbarProvider>
);

export default meta;
type Story = StoryObj<typeof AccessRightsForm>;

export const Default: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: defaultAccessRights,
    labels,
    link: 'link',
    roles,
    submit: () => undefined
  },
  render: Template
};

export const AccessRightsWithStates: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: accessRightsWithStates,
    labels,
    link: 'link',
    roles,
    submit: () => undefined
  },
  render: Template
};

export const withEmptyState: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: emptyAccessRights,
    labels,
    link: 'link',
    roles,
    submit: () => undefined
  },
  render: Template
};

export const withoutLink: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: defaultAccessRights,
    labels,
    roles,
    submit: () => undefined
  },
  render: Template
};

export const loading: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: emptyAccessRights,
    labels,
    link: 'link',
    loading: true,
    roles,
    submit: () => undefined
  },
  render: Template
};

==> centreon-web-24.10.17.tar.gz: centreon-web-24.10.17/packages/ui/src/components/Form/AccessRights/AccessRights.stories.tsx <==
import { Meta, StoryObj } from '@storybook/react';
import { http, HttpResponse } from 'msw';

import { SnackbarProvider } from '../../..';

import { AccessRights } from './AccessRights';
import {
  accessRightsWithStates,
  buildResult,
  defaultAccessRights,
  emptyAccessRights,
  labels,
  roles
} from './storiesData';

const meta: Meta<typeof AccessRights> = {
  component: AccessRights,
  parameters: {
    msw: {
      handlers: [
        http.get('api/latest/contact?**', () => {
          return HttpResponse.json(buildResult(false));
        }),
        http.get('api/latest/contactGroup?**', () => {
          return HttpResponse.json(buildResult(true));
        })
      ]
    }
  }
};

const Template = (args): JSX.Element => (
  <SnackbarProvider>
    <AccessRights {...args} />
  </SnackbarProvider>
);

export default meta;
type Story = StoryObj<typeof AccessRights>;

export const Default: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: defaultAccessRights,
    labels,
    roles,
    submit: () => undefined
  },
  render: Template
};

export const AccessRightsWithStates: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: accessRightsWithStates,
    labels,
    roles,
    submit: () => undefined
  },
  render: Template
};

export const withEmptyState: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: emptyAccessRights,
    labels,
    roles,
    submit: () => undefined
  },
  render: Template
};

export const loading: Story = {
  args: {
    cancel: () => undefined,
    endpoints: {
      contact: '/contact',
      contactGroup: '/contactGroup'
    },
    initialValues: emptyAccessRights,
    labels,
    loading: true,
    roles,
    submit: () => undefined
  },
  render: Template
};
